NXSConfigServer Tango Class Command ComponentsDataSources

Command ComponentsDataSources :

Returns a list of datasource names for a given components

ComponentsDataSources Definition
Input Argument | Tango::DEVVAR_STRINGARRAY | component names
Output Argument | Tango::DEVVAR_STRINGARRAY | list of datasource names
DisplayLevel | OPERATOR | ..
Inherited | false | ..
Abstract | false | ..
Polling Period | Not polled | ..
Command NOT allowed for | ON RUNNING | ..